import { Extension } from '@codemirror/state';

/**
 * Options for the indent wrapped lines extension
 */
interface IndentWrappedLinesOptions {
    /**
     * The initial indent for the wrapped lines
     * This indent is added before calculating the rest of the indent
     * @default 0
     */
    initialIndent: number;
    /**
     * Determines the type of indent to use for the initial indent
     * This indent is added before calculating the rest of the indent
     * @default "space"
     */
    initialIndentType: "space" | "tab" | "indentUnit";
}

/**
 * An extension for CodeMirror to indent wrapped lines
 * This extension also contains the extension to enable line wrapping
 *
 * @param options Options for the indent wrapped lines extension
 * @returns A CodeMirror extension
 */
declare function indentWrappedLines(options?: Partial<IndentWrappedLinesOptions>): Extension;

export { indentWrappedLines };
